@@ -78,7 +78,7 @@ class TcpStateTool(Tool):
             elif 'timed out' in errmsg:
                 state = 'filtered'
             else:
-                state = errmsg.replace(' ', '-')
+                state = errmsg.replace(' ', '-').replace(',', '-')
                 self.stderr = True
         except gevent.GreenletExit:
             #
